@@ -1,4 +1,4 @@
-#define LOCALEDIR "./locale"
+#define LOCALEDIR ".\\share\\locale"
 #define ENABLE_NLS
 #define USE_GMODULE
 #define USE_PLUGIN
@@ -7,12 +7,12 @@
 #define USE_IPV6
 #define HAVE_ISO_CODES
 #define PACKAGE_NAME "hexchat"
-#define PACKAGE_VERSION "2.9.4"
+#define PACKAGE_VERSION "2.9.5"
 #define HEXCHATLIBDIR "."
 #define HEXCHATSHAREDIR "."
 #define OLD_PERL
 #define GETTEXT_PACKAGE "hexchat"
-#define PACKAGE_TARNAME "hexchat-2.9.4"
+#define PACKAGE_TARNAME "hexchat-2.9.5"
 #ifndef USE_IPV6
 #define socklen_t int
 #endif
