@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <stdlib.h>
@@ -1042,7 +1042,7 @@ XS (XS_Xchat_hook_fd)
 
 	dXSARGS;
 
-	if (items != 4) {
+	if (items != 5) {
 		hexchat_print (ph,
 						 "Usage: Xchat::Internal::hook_fd(fd, callback, flags, userdata)");
 	} else {
@@ -1420,20 +1420,19 @@ perl_load_file (char *filename)
 				if (lib) {
 					FreeLibrary (lib);
 					lib = NULL;
-					thread_mbox ("Cannot open " PERL_DLL "\n\n"
-									 "You must have either ActivePerl or Straberry Perl"
-									 PERL_REQUIRED_VERSION
-									 " installed in order to\n"
-									 "run perl scripts.\n\n"
+					thread_mbox ("Cannot open " PERL_DLL "!\n\n"
+									 "You must have a Visual C++ build of Perl "
+									 PERL_REQUIRED_VERSION " installed in order to\n"
+									 "run Perl scripts. A reboot may be required.\n\n"
+									 "http://hexchat.org/downloads.html\n\n"
 									 "I have found Perl 5.6, but that is too old.");
 				} else {
-					thread_mbox ("Cannot open " PERL_DLL "\n\n"
-									 "You must have either ActivePerl or Strawberry Perl "
+					thread_mbox ("Cannot open " PERL_DLL "!\n\n"
+									 "You must have a Visual C++ build of Perl "
 									 PERL_REQUIRED_VERSION " installed in order to\n"
-									 "run perl scripts.\n\n"
-									 "http://www.activestate.com/ActivePerl/\n"
-									 "http://strawberryperl.com/\n"
-									 "Make sure perl's bin directory is in your PATH.");
+									 "run Perl scripts. A reboot may be required.\n\n"
+									 "http://hexchat.org/downloads.html\n\n"
+									 "Make sure Perl's bin directory is in your PATH.");
 				}
 			}
 			/* failure */
