@@ -15,7 +15,7 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this file; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
 /* Thread support
@@ -66,6 +66,7 @@
 #endif
 
 #include "hexchat-plugin.h"
+#undef _POSIX_C_SOURCE	/* Avoid warning: also in /usr/include/features.hfrom glib.h */
 #include "Python.h"
 #include "structmember.h"
 #include "pythread.h"
@@ -1609,12 +1610,15 @@ Module_hexchat_pluginpref_get(PyObject *self, PyObject *args)
 	if (!PyArg_ParseTuple(args, "s:get_pluginpref", &var))
 		return NULL;
 	// This will always return numbers as integers.
-	retint = hexchat_pluginpref_get_int(ph, var);
 	if (hexchat_pluginpref_get_str(ph, var, retstr)) {
-		if ((retint == 0) && (strcmp(retstr, "0") != 0))
+		if (strlen (retstr) <= 12) {
+			retint = hexchat_pluginpref_get_int(ph, var);
+			if ((retint == 0) && (strcmp(retstr, "0") != 0))
+				ret = PyString_FromString(retstr);
+			else
+				ret = PyInt_FromLong(retint);
+		} else
 			ret = PyString_FromString(retstr);
-		else
-			ret = PyInt_FromLong(retint);
 	}
 	else
 		ret = Py_None;
@@ -2137,6 +2141,7 @@ Command_PyReload(char *name)
 		char *filename = strdup(plugin->filename);
 		Command_PyUnload(filename);
 		Command_PyLoad(filename);
+		/* cppcheck-suppress deallocDealloc */
 		g_free(filename);
 	}
 }
