@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <fcntl.h>
@@ -330,7 +330,7 @@ get_xdir (void)
 			xdir = g_strdup_printf ("%s\\" "HexChat", out);
 		}
 #else
-		xdir = g_strdup_printf ("%s/.config/" HEXCHAT_DIR, g_get_home_dir ());
+		xdir = g_strdup_printf ("%s/" HEXCHAT_DIR, g_get_user_config_dir ());
 #endif
 	}
 
@@ -435,6 +435,7 @@ const struct prefs vars[] =
 	{"gui_lagometer", P_OFFINT (hex_gui_lagometer), TYPE_INT},
 	{"gui_lang", P_OFFINT (hex_gui_lang), TYPE_INT},
 	{"gui_mode_buttons", P_OFFINT (hex_gui_mode_buttons), TYPE_BOOL},
+	{"gui_pane_divider_position", P_OFFINT (hex_gui_pane_divider_position), TYPE_INT},
 	{"gui_pane_left_size", P_OFFINT (hex_gui_pane_left_size), TYPE_INT},
 	{"gui_pane_right_size", P_OFFINT (hex_gui_pane_right_size), TYPE_INT},
 	{"gui_pane_right_size_min", P_OFFINT (hex_gui_pane_right_size_min), TYPE_INT},
@@ -449,7 +450,6 @@ const struct prefs vars[] =
 	{"gui_tab_icons", P_OFFINT (hex_gui_tab_icons), TYPE_BOOL},
 	{"gui_tab_layout", P_OFFINT (hex_gui_tab_layout), TYPE_INT},
 	{"gui_tab_newtofront", P_OFFINT (hex_gui_tab_newtofront), TYPE_INT},
-	{"gui_tab_notices", P_OFFINT (hex_gui_tab_notices), TYPE_BOOL},
 	{"gui_tab_pos", P_OFFINT (hex_gui_tab_pos), TYPE_INT},
 	{"gui_tab_server", P_OFFINT (hex_gui_tab_server), TYPE_BOOL},
 	{"gui_tab_small", P_OFFINT (hex_gui_tab_small), TYPE_INT},
@@ -459,10 +459,13 @@ const struct prefs vars[] =
 	{"gui_throttlemeter", P_OFFINT (hex_gui_throttlemeter), TYPE_INT},
 	{"gui_topicbar", P_OFFINT (hex_gui_topicbar), TYPE_BOOL},
 	{"gui_tray", P_OFFINT (hex_gui_tray), TYPE_BOOL},
+	{"gui_tray_away", P_OFFINT (hex_gui_tray_away), TYPE_BOOL},
+	{"gui_tray_blink", P_OFFINT (hex_gui_tray_blink), TYPE_BOOL},
 	{"gui_tray_close", P_OFFINT (hex_gui_tray_close), TYPE_BOOL},
 	{"gui_tray_minimize", P_OFFINT (hex_gui_tray_minimize), TYPE_BOOL},
 	{"gui_tray_quiet", P_OFFINT (hex_gui_tray_quiet), TYPE_BOOL},
 	{"gui_ulist_buttons", P_OFFINT (hex_gui_ulist_buttons), TYPE_BOOL},
+	{"gui_ulist_color", P_OFFINT (hex_gui_ulist_color), TYPE_BOOL},
 	{"gui_ulist_count", P_OFFINT (hex_gui_ulist_count), TYPE_BOOL},
 	{"gui_ulist_doubleclick", P_OFFSET (hex_gui_ulist_doubleclick), TYPE_STR},
 	{"gui_ulist_hide", P_OFFINT (hex_gui_ulist_hide), TYPE_BOOL},
@@ -520,6 +523,7 @@ const struct prefs vars[] =
 	{"irc_nick3", P_OFFSET (hex_irc_nick3), TYPE_STR},
 	{"irc_nick_hilight", P_OFFSET (hex_irc_nick_hilight), TYPE_STR},
 	{"irc_no_hilight", P_OFFSET (hex_irc_no_hilight), TYPE_STR},
+	{"irc_notice_pos", P_OFFINT (hex_irc_notice_pos), TYPE_INT},
 	{"irc_part_reason", P_OFFSET (hex_irc_part_reason), TYPE_STR},
 	{"irc_quit_reason", P_OFFSET (hex_irc_quit_reason), TYPE_STR},
 	{"irc_raw_modes", P_OFFINT (hex_irc_raw_modes), TYPE_BOOL},
@@ -616,7 +620,7 @@ convert_with_fallback (const char *str, const char *fallback)
 void
 load_config (void)
 {
-	char *cfg, *sp;
+	char *cfg, *sp, *buf;
 	const char *username, *realname;
 	int res, val, i;
 #ifdef WIN32
@@ -667,6 +671,7 @@ load_config (void)
 	prefs.hex_gui_tab_sort = 1;
 	prefs.hex_gui_topicbar = 1;
 	prefs.hex_gui_tray = 1;
+	prefs.hex_gui_tray_blink = 1;
 	prefs.hex_gui_ulist_count = 1;
 	prefs.hex_gui_ulist_icons = 1;
 	prefs.hex_gui_ulist_resizable = 1;
@@ -678,6 +683,7 @@ load_config (void)
 	prefs.hex_input_tray_hilight = 1;
 	prefs.hex_input_tray_priv = 1;
 	/* prefs.hex_irc_who_join = 1; prevent kicks and bans caused by overwhelming who'ing after reconnects */
+	prefs.hex_irc_whois_front = 1;
 	prefs.hex_net_auto_reconnect = 1;
 	prefs.hex_net_throttle = 1;
 	prefs.hex_stamp_log = 1;
@@ -749,7 +755,10 @@ load_config (void)
 		snprintf (prefs.hex_dcc_dir, sizeof (prefs.hex_dcc_dir), "%s\\Downloads", out);
 	}
 #else
-	snprintf (prefs.hex_dcc_dir, sizeof (prefs.hex_dcc_dir), "%s/downloads", get_xdir ());
+	if (g_get_user_special_dir(G_USER_DIRECTORY_DOWNLOAD))
+		strcpy (prefs.hex_dcc_dir, g_get_user_special_dir(G_USER_DIRECTORY_DOWNLOAD));
+	else
+		strcpy (prefs.hex_dcc_dir, g_build_filename (g_get_home_dir (), "Downloads", NULL));
 #endif
 	strcpy (prefs.hex_dnsprogram, "host");
 	strcpy (prefs.hex_gui_ulist_doubleclick, "QUERY %s");
@@ -829,6 +838,10 @@ load_config (void)
 
 		g_mkdir (prefs.hex_dcc_dir, 0700);
 		g_mkdir (prefs.hex_dcc_completed_dir, 0700);
+
+		buf = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "addons", get_xdir ());
+		g_mkdir (buf, 0700);
+		g_free (buf);
 	}
 	if (prefs.hex_gui_win_height < 138)
 		prefs.hex_gui_win_height = 138;
@@ -844,25 +857,23 @@ int
 save_config (void)
 {
 	int fh, i;
-	char *new_config, *config;
+	char *config, *new_config;
 
 	check_prefs_dir ();
 
 	config = default_file ();
-	new_config = malloc (strlen (config) + 5);
-	strcpy (new_config, config);
-	strcat (new_config, ".new");
+	new_config = g_strconcat (config, ".new", NULL);
 	
-	fh = open (new_config, OFLAGS | O_TRUNC | O_WRONLY | O_CREAT, 0600);
+	fh = g_open (new_config, OFLAGS | O_TRUNC | O_WRONLY | O_CREAT, 0600);
 	if (fh == -1)
 	{
-		free (new_config);
+		g_free (new_config);
 		return 0;
 	}
 
 	if (!cfg_put_str (fh, "version", PACKAGE_VERSION))
 	{
-		free (new_config);
+		g_free (new_config);
 		return 0;
 	}
 		
@@ -874,7 +885,7 @@ save_config (void)
 		case TYPE_STR:
 			if (!cfg_put_str (fh, vars[i].name, (char *) &prefs + vars[i].offset))
 			{
-				free (new_config);
+				g_free (new_config);
 				return 0;
 			}
 			break;
@@ -882,7 +893,7 @@ save_config (void)
 		case TYPE_BOOL:
 			if (!cfg_put_int (fh, *((int *) &prefs + vars[i].offset), vars[i].name))
 			{
-				free (new_config);
+				g_free (new_config);
 				return 0;
 			}
 		}
@@ -892,19 +903,19 @@ save_config (void)
 
 	if (close (fh) == -1)
 	{
-		free (new_config);
+		g_free (new_config);
 		return 0;
 	}
 
 #ifdef WIN32
-	unlink (config);	/* win32 can't rename to an existing file */
+	g_unlink (config);	/* win32 can't rename to an existing file */
 #endif
-	if (rename (new_config, config) == -1)
+	if (g_rename (new_config, config) == -1)
 	{
-		free (new_config);
+		g_free (new_config);
 		return 0;
 	}
-	free (new_config);
+	g_free (new_config);
 
 	return 1;
 }
