@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <stdlib.h>
@@ -471,13 +471,10 @@ plugin_auto_load (session *sess)
 	for_files (".\\plugins", "hcdoat.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcexec.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcfishlim.dll", plugin_auto_load_cb);
-	for_files (".\\plugins", "hchextray.dll", plugin_auto_load_cb);
-	for_files (".\\plugins", "hclua.dll", plugin_auto_load_cb);
+	/* for_files (".\\plugins", "hchextray.dll", plugin_auto_load_cb); don't load HexTray until it's fixed */
 	for_files (".\\plugins", "hcmpcinfo.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcperl.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcpython.dll", plugin_auto_load_cb);
-	/* for_files (".\\plugins", "hcsasl.dll", plugin_auto_load_cb); we have this built-in */
-	for_files (".\\plugins", "hctcl.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcupd.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcwinamp.dll", plugin_auto_load_cb);
 	for_files (".\\plugins", "hcsysinfo.dll", plugin_auto_load_cb);
@@ -1629,6 +1626,7 @@ hexchat_pluginpref_set_str_real (hexchat_plugin *pl, const char *var, const char
 	char *buffer;
 	char *buffer_tmp;
 	char line_buffer[512];		/* the same as in cfg_put_str */
+	char *line_bufp = line_buffer;
 	char *canon;
 
 	canon = g_strdup (pl->name);
@@ -1690,7 +1688,7 @@ hexchat_pluginpref_set_str_real (hexchat_plugin *pl, const char *var, const char
 	{
 		prevSetting = 0;
 
-		while (fscanf (fpIn, " %[^\n]", &line_buffer) != EOF)	/* read whole lines including whitespaces */
+		while (fscanf (fpIn, " %[^\n]", line_bufp) != EOF)	/* read whole lines including whitespaces */
 		{
 			buffer_tmp = g_strdup_printf ("%s ", var);	/* add one space, this way it works against var - var2 checks too */
 
@@ -1847,6 +1845,7 @@ hexchat_pluginpref_list (hexchat_plugin *pl, char* dest)
 	FILE *fpIn;
 	char confname[64];
 	char buffer[512];										/* the same as in cfg_put_str */
+	char *bufp = buffer;
 	char *token;
 
 	token = g_strdup (pl->name);
@@ -1863,7 +1862,7 @@ hexchat_pluginpref_list (hexchat_plugin *pl, char* dest)
 	else													/* existing config file, get list of settings */
 	{
 		strcpy (dest, "");									/* clean up garbage */
-		while (fscanf (fpIn, " %[^\n]", &buffer) != EOF)	/* read whole lines including whitespaces */
+		while (fscanf (fpIn, " %[^\n]", bufp) != EOF)	/* read whole lines including whitespaces */
 		{
 			token = strtok (buffer, "=");
 			strncat (dest, token, strlen (token) - 1);
