@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <stdlib.h>
@@ -264,6 +264,9 @@ static const struct defaultserver def[] =
 /*	{0,			"sprynet.us.galaxynet.org"},
 	{0,			"atlanta.ga.us.galaxynet.org"},*/
 
+	{"GameSurge",	0},
+	{0,			"irc.gamesurge.net"},
+	
 /*	{"GamesNET",	0},
 	{0,				"irc.gamesnet.net"},
 	{0,				"irc.us.gamesnet.net"},
@@ -321,7 +324,6 @@ static const struct defaultserver def[] =
 	{0,			"tonsberg.no.eu.irclink.net"},
 
 	{"IRCNet",		0},
-	{0,				"irc.ircnet.com"},
 	{0,				"irc.stealth.net/6668"},
 	{0,				"ircnet.demon.co.uk"},
 /*	{0,				"ircnet.hinet.hr"},*/
@@ -382,6 +384,9 @@ static const struct defaultserver def[] =
 	{"MIXXnet",		0},
 	{0,			"irc.mixxnet.net"},
 
+	{"Moznet",		0},
+	{0,			"irc.mozilla.org"},
+
 	{"NeverNET",	0},
 	{0,			"irc.nevernet.net"},
 	{0,			"imagine.nevernet.net"},
@@ -487,9 +492,12 @@ static const struct defaultserver def[] =
 
 	{"Snoonet", 0},
 #ifdef USE_OPENSSL
-	{0,			"irc.snoonet.com/+6697"},
+	{0,			"irc.snoonet.org/+6697"},
 #endif
-	{0,			"irc.snoonet.com/6667"},
+	{0,			"irc.snoonet.org/6667"},
+
+	{"Snyde", 0},
+	{0,			"irc.snyde.net/6667"},
 
 	{"Sohbet.Net", 0},
 	{0,			"irc.sohbet.net"},
@@ -506,6 +514,12 @@ static const struct defaultserver def[] =
 	{0,			"us.spidernet.org"},
 	{0,			"eu.spidernet.org"},
 	{0,			"irc.spidernet.org"},*/
+	
+	{"SpotChat", 0},
+#ifdef USE_OPENSSL
+	{0,			"irc.spotchat.org/+6697"},
+#endif
+	{0,			"irc.spotchat.org/6667"},
 
 	{"StarChat", 0},
 	{0,			"irc.starchat.net"},
@@ -516,6 +530,12 @@ static const struct defaultserver def[] =
 	{0,			"tahoma.starchat.net"},
 	{0,			"neo.starchat.net"},
 
+	{"Station51", 0},
+#ifdef USE_OPENSSL
+	{0,			"irc.station51.net/+6697"},
+#endif
+	{0,			"irc.station51.net"},
+	
 	{"SwiftIRC", 0},
 #ifdef USE_OPENSSL
 	{0,			"irc.swiftirc.net/+6697"},
@@ -1036,7 +1056,19 @@ servlist_load (void)
 	char *tmp;
 	ircnet *net = NULL;
 
-	fp = hexchat_fopen_file ("servlist_.conf", "r", 0);
+	/* simple migration we will keep for a short while */
+	char *oldfile = g_build_filename (get_xdir (), "servlist_.conf", NULL);
+	char *newfile = g_build_filename (get_xdir (), "servlist.conf", NULL);
+
+	if (g_file_test (oldfile, G_FILE_TEST_EXISTS) && !g_file_test (newfile, G_FILE_TEST_EXISTS))
+	{
+		g_rename (oldfile, newfile);
+	}
+
+	g_free (oldfile);
+	g_free (newfile);
+
+	fp = hexchat_fopen_file ("servlist.conf", "r", 0);
 	if (!fp)
 		return FALSE;
 
@@ -1167,12 +1199,12 @@ servlist_save (void)
 #ifndef WIN32
 	int first = FALSE;
 
-	buf = g_strdup_printf ("%s/servlist_.conf", get_xdir ());
+	buf = g_strdup_printf ("%s/servlist.conf", get_xdir ());
 	if (g_access (buf, F_OK) != 0)
 		first = TRUE;
 #endif
 
-	fp = hexchat_fopen_file ("servlist_.conf", "w", 0);
+	fp = hexchat_fopen_file ("servlist.conf", "w", 0);
 	if (!fp)
 	{
 #ifndef WIN32
