@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #define WANTSOCKET
@@ -1319,8 +1319,17 @@ int my_poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
 	    if (*argv[argc]) {
 		buf++, argc++;
 		if (argc == argvAlloced) {
+		    char **temp;
 		    argvAlloced += POPT_ARGV_ARRAY_GROW_DELTA;
-		    argv = realloc(argv, sizeof(*argv) * argvAlloced);
+		    temp = realloc(argv, sizeof(*argv) * argvAlloced);
+		    if (temp)
+			argv = temp;
+		    else
+		    {
+			free(argv);
+			free(bufStart);
+			return 1;
+		    }
 		}
 		argv[argc] = buf;
 	    }
@@ -1607,25 +1616,25 @@ file_exists (char *fname)
 }
 
 static gboolean
-copy_file (char *dl_src, char *dl_dest, int permissions)	/* FS encoding */
+copy_file (char *dl_src, char *dl_dest, int permissions)
 {
 	int tmp_src, tmp_dest;
 	gboolean ok = FALSE;
 	char dl_tmp[4096];
 	int return_tmp, return_tmp2;
 
-	if ((tmp_src = open (dl_src, O_RDONLY | OFLAGS)) == -1)
+	if ((tmp_src = g_open (dl_src, O_RDONLY | OFLAGS, 0600)) == -1)
 	{
-		fprintf (stderr, "Unable to open() file '%s' (%s) !", dl_src,
+		g_fprintf (stderr, "Unable to open() file '%s' (%s) !", dl_src,
 				  strerror (errno));
 		return FALSE;
 	}
 
 	if ((tmp_dest =
-		 open (dl_dest, O_WRONLY | O_CREAT | O_TRUNC | OFLAGS, permissions)) < 0)
+		 g_open (dl_dest, O_WRONLY | O_CREAT | O_TRUNC | OFLAGS, permissions)) < 0)
 	{
 		close (tmp_src);
-		fprintf (stderr, "Unable to create file '%s' (%s) !", dl_src,
+		g_fprintf (stderr, "Unable to create file '%s' (%s) !", dl_src,
 				  strerror (errno));
 		return FALSE;
 	}
@@ -1868,6 +1877,17 @@ hextray_mode ()
 #endif
 }
 
+int
+unity_mode ()
+{
+#ifdef G_OS_UNIX
+	const char *env = g_getenv("XDG_CURRENT_DESKTOP");
+	if (env && strcmp (env, "Unity") == 0)
+		return 1;
+#endif
+	return 0;
+}
+
 /* Routine for listing subfolders of a given folder. ALWAYS free correctly after use, e.g.
 void display_list (GSList *list)
 {
