@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <stdio.h>
@@ -149,7 +149,7 @@ create_msg_dialog (gchar *title, gchar *message)
 {
 	GtkWidget *dialog;
 
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, message);
+	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", message);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
 /* On Win32 we automatically have the icon. If we try to load it explicitly, it will look ugly for some reason. */
@@ -604,14 +604,6 @@ fe_is_chanwindow (struct server *serv)
 	return 1;
 }
 
-int
-fe_is_banwindow (struct session *sess)
-{
-   if (!sess->res->banlist_window)
-     return 0;
-   return 1;
-}
-
 void
 fe_notify_update (char *name)
 {
@@ -674,6 +666,7 @@ fe_print_text (struct session *sess, char *text, time_t stamp)
 		 sess->gui->is_tab && !sess->nick_said && stamp == 0)
 	{
 		sess->new_data = TRUE;
+		lastact_update (sess);
 		if (sess->msg_said)
 			fe_set_tab_color (sess, 2);
 		else
@@ -682,9 +675,10 @@ fe_print_text (struct session *sess, char *text, time_t stamp)
 }
 
 void
-fe_beep (void)
+fe_beep (session *sess)
 {
-	gdk_beep ();
+	if (fe_gui_info (sess, 0) != 1)
+		gdk_beep ();
 }
 
 void
@@ -988,9 +982,9 @@ fe_set_inputbox_contents (session *sess, char *text)
 #ifndef WIN32
 
 static gboolean
-try_browser (const char *browser, const char *arg, const char *url)
+try_browser (const char *browser, char *arg, const char *url)
 {
-	const char *argv[4];
+	char *argv[4];
 	char *path;
 
 	path = g_find_program_in_path (browser);
@@ -998,12 +992,12 @@ try_browser (const char *browser, const char *arg, const char *url)
 		return 0;
 
 	argv[0] = path;
-	argv[1] = url;
+	argv[1] = (char *)url;
 	argv[2] = NULL;
 	if (arg)
 	{
 		argv[1] = arg;
-		argv[2] = url;
+		argv[2] = (char *)url;
 		argv[3] = NULL;
 	}
 	hexchat_execv (argv);
@@ -1021,21 +1015,26 @@ fe_open_url_inner (const char *url)
 #elif defined __APPLE__
 	try_browser ("open", NULL, url);				/* on Mac you can just 'open http://foo.bar/' */
 #else
+
+	/* lets try what gtk has built in first. */
+	if (gtk_show_uri (NULL, url, GDK_CURRENT_TIME, NULL))
+		return;
+		
 	/* universal desktop URL opener (from xdg-utils). Supports gnome,kde,xfce4. */
 	if (try_browser ("xdg-open", NULL, url))
 		return;
 
-	/* try to detect GNOME */
+	/* try to detect GNOME (this env variable is depreciated) */
 	if (g_getenv ("GNOME_DESKTOP_SESSION_ID"))
 	{
-		if (try_browser ("gnome-open", NULL, url)) /* Gnome 2.4+ has this */
+		if (try_browser ("gvfs-open", NULL, url))
 			return;
 	}
 
 	/* try to detect KDE */
 	if (g_getenv ("KDE_FULL_SESSION"))
 	{
-		if (try_browser ("kfmclient", "exec", url))
+		if (try_browser ("kde-open", NULL, url))
 			return;
 	}
 
@@ -1043,8 +1042,8 @@ fe_open_url_inner (const char *url)
 	if (try_browser ("firefox", NULL, url))
 		return;
 
-	/* fresh out of ideas... */
-	try_browser ("mozilla", NULL, url);
+	/* fresh out of ideas... i hear chromium is popular */
+	try_browser ("chromium", NULL, url);
 #endif
 }
 
@@ -1052,7 +1051,7 @@ static void
 fe_open_url_locale (const char *url)
 {
 	/* the http:// part's missing, prepend it, otherwise it won't always work */
-	if (strchr (url, ':') == NULL && url_check_word (url, strlen (url)) != WORD_PATH)
+	if (strchr (url, ':') == NULL && url_check_word (url) != WORD_PATH)
 	{
 		url = g_strdup_printf ("http://%s", url);
 		fe_open_url_inner (url);
