@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <stdio.h>
@@ -1258,7 +1258,7 @@ savebuffer_req_done (session *sess, char *file)
 	if (!file)
 		return;
 
-	fh = open (file, O_TRUNC | O_WRONLY | O_CREAT, 0600);
+	fh = g_open (file, O_TRUNC | O_WRONLY | O_CREAT, 0600);
 	if (fh != -1)
 	{
 		gtk_xtext_save (GTK_XTEXT (sess->gui->xtext), fh);
@@ -1503,7 +1503,7 @@ menu_ctcpguiopen (void)
 static void
 menu_docs (GtkWidget *wid, gpointer none)
 {
-	fe_open_url ("http://www.hexchat.org/");
+	fe_open_url ("http://docs.hexchat.org/");
 }
 
 /*static void
