@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <stdio.h>
@@ -130,8 +130,8 @@ pixmaps_init (void)
 
 	/* tray icons, with inlined defaults */
 	pix_tray_fileoffer = load_pixmap ("tray_fileoffer", png_tray_fileoffer, 1);
-	pix_tray_highlight = load_pixmap ("highlight", png_tray_highlight, 1);
-	pix_tray_message = load_pixmap ("message", png_tray_message, 1);
+	pix_tray_highlight = load_pixmap ("tray_highlight", png_tray_highlight, 1);
+	pix_tray_message = load_pixmap ("tray_message", png_tray_message, 1);
 
 #if 0
 	/* treeview icons, no defaults, load from disk only */
