@@ -1,4 +1,20 @@
-/* Copyright (C) 2006-2007 Peter Zelezny. */
+/* X-Chat
+ * Copyright (C) 2006-2007 Peter Zelezny.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <string.h>
 #include "../common/hexchat-plugin.h"
@@ -60,6 +76,10 @@ typedef GdkPixbuf* TrayIcon;
 static GtkStatusIcon *sticon;
 static gint flash_tag;
 static TrayStatus tray_status;
+#ifdef WIN32
+static guint tray_menu_timer;
+static gint64 tray_menu_inactivetime;
+#endif
 static hexchat_plugin *ph;
 
 static TrayIcon custom_icon1;
@@ -69,9 +89,13 @@ static int tray_priv_count = 0;
 static int tray_pub_count = 0;
 static int tray_hilight_count = 0;
 static int tray_file_count = 0;
+static int tray_restore_timer = 0;
 
 
 void tray_apply_setup (void);
+static gboolean tray_menu_try_restore ();
+static void tray_cleanup (void);
+static void tray_init (void);
 
 
 static WinStatus
@@ -165,7 +189,11 @@ fe_tray_set_balloon (const char *title, const char *text)
 	notify_text = strip_color (text, -1, STRIP_ALL|STRIP_ESCMARKUP);
 	notify_title = strip_color (title, -1, STRIP_ALL);
 
-	notification = XC_NOTIFY_NEW (notify_title, notify_text, HEXCHATSHAREDIR"/pixmaps/hexchat.png", NULL);
+	notification = XC_NOTIFY_NEW (notify_title, notify_text, HEXCHATSHAREDIR "/icons/hicolor/scalable/apps/hexchat.svg", NULL);
+
+#if NOTIFY_CHECK_VERSION(0,7,0)
+	notify_notification_set_hint (notification, "desktop-entry", g_variant_new_string ("hexchat"));
+#endif
 
 	g_free ((char *)notify_title);
 	g_free ((char *)notify_text);
@@ -297,7 +325,8 @@ tray_set_flash (TrayIcon icon)
 	tray_stop_flash ();
 
 	gtk_status_icon_set_from_pixbuf (sticon, icon);
-	flash_tag = g_timeout_add (TIMEOUT, (GSourceFunc) tray_timeout_cb, icon);
+	if (prefs.hex_gui_tray_blink)
+		flash_tag = g_timeout_add (TIMEOUT, (GSourceFunc) tray_timeout_cb, icon);
 }
 
 void
@@ -368,6 +397,7 @@ tray_toggle_visibility (gboolean force_hide)
 {
 	static int x, y;
 	static GdkScreen *screen;
+	static int maximized;
 	GtkWindow *win;
 
 	if (!sticon)
@@ -390,14 +420,21 @@ tray_toggle_visibility (gboolean force_hide)
 	if (force_hide || GTK_WIDGET_VISIBLE (win))
 #endif
 	{
+		if (prefs.hex_gui_tray_away)
+			hexchat_command (ph, "ALLSERV AWAY");
 		gtk_window_get_position (win, &x, &y);
 		screen = gtk_window_get_screen (win);
+		maximized = prefs.hex_gui_win_state;
 		gtk_widget_hide (GTK_WIDGET (win));
 	}
 	else
 	{
+		if (prefs.hex_gui_tray_away)
+			hexchat_command (ph, "ALLSERV BACK");
 		gtk_window_set_screen (win, screen);
 		gtk_window_move (win, x, y);
+		if (maximized)
+			gtk_window_maximize (win);
 		gtk_widget_show (GTK_WIDGET (win));
 		gtk_window_present (win);
 	}
@@ -411,6 +448,34 @@ tray_menu_restore_cb (GtkWidget *item, gpointer userdata)
 	tray_toggle_visibility (FALSE);
 }
 
+static void
+tray_menu_notify_cb (GObject *tray, GParamSpec *pspec, gpointer user_data)
+{
+	if (sticon)
+	{
+		if (!gtk_status_icon_is_embedded (sticon))
+		{
+			tray_restore_timer = g_timeout_add(500, (GSourceFunc)tray_menu_try_restore, NULL);
+		}
+		else
+		{
+			if (tray_restore_timer)
+			{
+				g_source_remove (tray_restore_timer);
+				tray_restore_timer = 0;
+			}
+		}
+	}
+}
+
+static gboolean
+tray_menu_try_restore ()
+{
+	tray_cleanup();
+	tray_init();
+	return TRUE;
+}
+
 static void
 tray_menu_quit_cb (GtkWidget *item, gpointer userdata)
 {
@@ -494,21 +559,58 @@ tray_menu_destroy (GtkWidget *menu, gpointer userdata)
 {
 	gtk_widget_destroy (menu);
 	g_object_unref (menu);
+#ifdef WIN32
+	g_source_remove (tray_menu_timer);
+#endif
 }
 
+#ifdef WIN32
+static void
+tray_menu_enter_cb (GtkWidget *menu)
+{
+	tray_menu_inactivetime = 0;
+}
+
+static void
+tray_menu_left_cb (GtkWidget *menu)
+{
+	tray_menu_inactivetime = g_get_real_time ();
+}
+
+static void
+tray_check_hide (GtkWidget *menu)
+{
+	if (tray_menu_inactivetime && g_get_real_time () - tray_menu_inactivetime  >= 2000000)
+	{
+		tray_menu_destroy (menu, NULL);
+	}
+}
+
+static void
+tray_menu_settings (GtkWidget * wid, gpointer none)
+{
+	extern void setup_open (void);
+	setup_open ();
+}
+#endif
+
 static void
 tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 {
-	GtkWidget *menu;
-#ifndef WIN32
+	static GtkWidget *menu;
 	GtkWidget *submenu;
 	GtkWidget *item;
 	int away_status;
-#endif
 
 	/* ph may have an invalid context now */
 	hexchat_set_context (ph, hexchat_find_context (ph, NULL, NULL));
 
+	/* close any old menu */
+	if (G_IS_OBJECT (menu))
+	{
+		tray_menu_destroy (menu, NULL);
+	}
+
 	menu = gtk_menu_new ();
 	/*gtk_menu_set_screen (GTK_MENU (menu), gtk_widget_get_screen (widget));*/
 
@@ -518,7 +620,7 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 		tray_make_item (menu, _("_Hide Window"), tray_menu_restore_cb, NULL);
 	tray_make_item (menu, NULL, tray_menu_quit_cb, NULL);
 
-#ifndef WIN32 /* somehow this is broken on win32 */
+#ifndef WIN32 /* submenus are buggy on win32 */
 	submenu = mg_submenu (menu, _("_Blink on"));
 	blink_item (&prefs.hex_input_tray_chans, submenu, _("Channel Message"));
 	blink_item (&prefs.hex_input_tray_priv, submenu, _("Private Message"));
@@ -526,6 +628,10 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 	/*blink_item (BIT_FILEOFFER, submenu, _("File Offer"));*/
 
 	submenu = mg_submenu (menu, _("_Change status"));
+#else /* so show away/back in main tray menu */
+	submenu = menu;
+#endif
+
 	away_status = tray_find_away_status ();
 	item = tray_make_item (submenu, _("_Away"), tray_foreach_server, "away");
 	if (away_status == 1)
@@ -534,20 +640,29 @@ tray_menu_cb (GtkWidget *widget, guint button, guint time, gpointer userdata)
 	if (away_status == 2)
 		gtk_widget_set_sensitive (item, FALSE);
 
-	tray_make_item (menu, NULL, tray_menu_quit_cb, NULL);
-#endif
-
-	mg_create_icon_item (_("_Quit"), GTK_STOCK_QUIT, menu, tray_menu_quit_cb, NULL);
-
 	menu_add_plugin_items (menu, "\x5$TRAY", NULL);
+#ifdef WIN32
+	tray_make_item (menu, NULL, tray_menu_quit_cb, NULL);
+	mg_create_icon_item (_("_Preferences"), GTK_STOCK_PREFERENCES, menu, tray_menu_settings, NULL);
+#endif
+	tray_make_item (menu, NULL, tray_menu_quit_cb, NULL);
+	mg_create_icon_item (_("_Quit"), GTK_STOCK_QUIT, menu, tray_menu_quit_cb, NULL);
 
 	g_object_ref (menu);
 	g_object_ref_sink (menu);
 	g_object_unref (menu);
 	g_signal_connect (G_OBJECT (menu), "selection-done",
 							G_CALLBACK (tray_menu_destroy), NULL);
+#ifdef WIN32
+	g_signal_connect (G_OBJECT (menu), "leave-notify-event",
+							G_CALLBACK (tray_menu_left_cb), NULL);
+	g_signal_connect (G_OBJECT (menu), "enter-notify-event",
+							G_CALLBACK (tray_menu_enter_cb), NULL);
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, gtk_status_icon_position_menu,
+	tray_menu_timer = g_timeout_add(500, (GSourceFunc) tray_check_hide, menu);
+#endif
+
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
 						 userdata, button, time);
 }
 
@@ -563,13 +678,14 @@ tray_init (void)
 	if (!sticon)
 		return;
 
-#ifndef WIN32
 	g_signal_connect (G_OBJECT (sticon), "popup-menu",
 							G_CALLBACK (tray_menu_cb), sticon);
-#endif
 
 	g_signal_connect (G_OBJECT (sticon), "activate",
 							G_CALLBACK (tray_menu_restore_cb), NULL);
+
+	g_signal_connect (G_OBJECT (sticon), "notify::embedded",
+							G_CALLBACK (tray_menu_notify_cb), NULL);
 }
 
 static int
@@ -737,7 +853,7 @@ tray_apply_setup (void)
 	}
 	else
 	{
-		if (prefs.hex_gui_tray && !hextray_mode ())
+		if (prefs.hex_gui_tray && !hextray_mode () && !unity_mode ())
 			tray_init ();
 	}
 }
@@ -769,7 +885,7 @@ tray_plugin_init (hexchat_plugin *plugin_handle, char **plugin_name,
 
 	hexchat_hook_print (ph, "Focus Window", -1, tray_focus_cb, NULL);
 
-	if (prefs.hex_gui_tray && !hextray_mode ())
+	if (prefs.hex_gui_tray && !hextray_mode () && !unity_mode ())
 		tray_init ();
 
 	return 1;       /* return 1 for success */
